@@ -1741,6 +1741,8 @@ class FacturaATR(Factura):
 
         for c in self.get_comptadors():
             for l in c.get_lectures(force_no_transforma_no_td_a_td=True):
+                if isinstance(l.consumo_calculado, int):
+                    return False
                 if not l.ajuste and not l.consumo_calculado.is_integer():
                     return True
 
@@ -2020,9 +2022,9 @@ class FacturaATR(Factura):
             for aparell in medida.modelos_aparatos:
                 try:
                     for integrador in aparell.integradores:
-                        if integrador.tipus == 'S' and  integrador.codigo_periodo not in ('10', '20', '30'):
+                        if integrador.tipus == 'S' and  integrador.codigo_periodo not in ('10', '20', '30', '90'):
                             return False
-                        elif integrador.tipus == 'S' and  integrador.codigo_periodo in ('10', '20', '30'):
+                        elif integrador.tipus == 'S' and  integrador.codigo_periodo in ('10', '20', '30', '90'):
                             has_p0 = True
                 except AttributeError:
                     pass
@@ -2105,26 +2107,32 @@ class FacturaATR(Factura):
                     comptador_amb_lectures = c
                     break
         if comptador_amb_lectures:
-            base_info = comptador_amb_lectures.get_lectures_activa_sortint()[0]
-            for concepte in self.conceptos_repercutibles:
-                if concepte.concepto_repercutible[0] == '7' and concepte.concepto_repercutible[1] != '1':
-                    l1 = Lectura(None)
-                    l1.fecha = base_info.lectura_desde.fecha
-                    l1.lectura = 0
-                    l1.procedencia = base_info.lectura_desde.procedencia
-                    l2 = Lectura(None)
-                    l2.fecha = base_info.lectura_hasta.fecha
-                    l2.lectura = 0
-                    l2.procedencia = base_info.lectura_hasta.procedencia
-                    new_integrador = Integrador(None)
-                    new_integrador.magnitud = "AS"
-                    new_integrador.numero_ruedas_enteras = base_info.numero_ruedas_enteras
-                    new_integrador.codigo_periodo = base_info.codigo_periodo[0] + concepte.concepto_repercutible[1]
-                    if not new_integrador.periode:
-                        new_integrador.codigo_periodo = base_info.codigo_periodo
-                    new_integrador.lectura_desde = l1
-                    new_integrador.lectura_hasta = l2
-                    res.append(new_integrador)
+            te_autoconsum = (self.autoconsumo and self.autoconsumo.energia_excedentaria) or ([x for x in (self.conceptos_repercutibles or []) if '7' == x.concepto_repercutible[0]])
+            if not te_autoconsum:
+                return res
+            base_info = comptador_amb_lectures.get_lectures_activa_entrant()[0]
+            i = 0
+            for consum in self.get_consum_facturat(tipus='S'):
+                i += 1
+                if i <= 1:
+                    continue
+                l1 = Lectura(None)
+                l1.fecha = base_info.lectura_desde.fecha
+                l1.lectura = 0
+                l1.procedencia = base_info.lectura_desde.procedencia
+                l2 = Lectura(None)
+                l2.fecha = base_info.lectura_hasta.fecha
+                l2.lectura = 0
+                l2.procedencia = base_info.lectura_hasta.procedencia
+                new_integrador = Integrador(None)
+                new_integrador.magnitud = "AS"
+                new_integrador.numero_ruedas_enteras = base_info.numero_ruedas_enteras
+                new_integrador.codigo_periodo = base_info.codigo_periodo[0] + str(i)
+                if not new_integrador.periode:
+                    new_integrador.codigo_periodo = base_info.codigo_periodo
+                new_integrador.lectura_desde = l1
+                new_integrador.lectura_hasta = l2
+                res.append(new_integrador)
         return res
 
     def get_lectures_amb_ajust_quadrat_amb_consum(self, tipus='S', ajust_balancejat=True, motiu_ajust="98", lectures=None):
